@@ -131,13 +131,19 @@ class http_downloader(object):
             body = req.read()
         except urlerror.HTTPError as E:
             code = E.getcode()
+            # More portability hax (no reason property in 2.6?)
+            try:
+                reason = E.reason
+            except AttributeError:
+                reason = "Connection error"
+
             if code == 404:
                 raise HTTPFileNotFoundError("File not found")
             elif code == 304:
                 raise HTTPStale(str(self._last_modified))
             else:
-                raise HTTPError("Server connection failed: {0.reason} ({1})".format(E, code))
-        except timeout:
+                raise HTTPError("Server connection failed: {0} ({1})".format(reason, code))
+        except (timeout, urlerror.URLError):
             raise HTTPTimeoutError("Server took too long to respond")
 
         lm = req.headers.get("last-modified")
@@ -169,7 +175,7 @@ class method_result(dict):
 
     def _call_method(self):
         """ Download the URL using last-modified timestamp if given """
-        self.update(json.loads(self._downloader.download().decode("utf-8", errors = "replace")))
+        self.update(json.loads(self._downloader.download().decode("utf-8")))
         self._fetched = True
 
     def get(self, key, default = None):
